@@ -23,7 +23,7 @@ from aliyunsdkrds.endpoint import endpoint_data
 class CheckCreateDdrDBInstanceRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'CheckCreateDdrDBInstance','rds')
+		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'CheckCreateDdrDBInstance')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -51,6 +51,11 @@ class CheckCreateDdrDBInstanceRequest(RpcRequest):
 
 	def set_EngineVersion(self, EngineVersion):  # String
 		self.add_query_param('EngineVersion', EngineVersion)
+	def get_ResourceGroupId(self): # String
+		return self.get_query_params().get('ResourceGroupId')
+
+	def set_ResourceGroupId(self, ResourceGroupId):  # String
+		self.add_query_param('ResourceGroupId', ResourceGroupId)
 	def get_Engine(self): # String
 		return self.get_query_params().get('Engine')
 
