@@ -24,7 +24,7 @@ import json
 class CreateDBInstanceRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'CreateDBInstance','rds')
+		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'CreateDBInstance')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -146,6 +146,11 @@ class CreateDBInstanceRequest(RpcRequest):
 
 	def set_AutoRenew(self, AutoRenew):  # String
 		self.add_query_param('AutoRenew', AutoRenew)
+	def get_Port(self): # String
+		return self.get_query_params().get('Port')
+
+	def set_Port(self, Port):  # String
+		self.add_query_param('Port', Port)
 	def get_RoleARN(self): # String
 		return self.get_query_params().get('RoleARN')
 
@@ -231,6 +236,11 @@ class CreateDBInstanceRequest(RpcRequest):
 
 	def set_Amount(self, Amount):  # Integer
 		self.add_query_param('Amount', Amount)
+	def get_AutoPay(self): # Boolean
+		return self.get_query_params().get('AutoPay')
+
+	def set_AutoPay(self, AutoPay):  # Boolean
+		self.add_query_param('AutoPay', AutoPay)
 	def get_ServerlessConfig(self): # Struct
 		return self.get_query_params().get('ServerlessConfig')
 
@@ -241,6 +251,11 @@ class CreateDBInstanceRequest(RpcRequest):
 
 	def set_UsedTime(self, UsedTime):  # String
 		self.add_query_param('UsedTime', UsedTime)
+	def get_BurstingEnabled(self): # Boolean
+		return self.get_query_params().get('BurstingEnabled')
+
+	def set_BurstingEnabled(self, BurstingEnabled):  # Boolean
+		self.add_query_param('BurstingEnabled', BurstingEnabled)
 	def get_TargetMinorVersion(self): # String
 		return self.get_query_params().get('TargetMinorVersion')
 
@@ -276,3 +291,8 @@ class CreateDBInstanceRequest(RpcRequest):
 
 	def set_PayType(self, PayType):  # String
 		self.add_query_param('PayType', PayType)
+	def get_BpeEnabled(self): # String
+		return self.get_query_params().get('BpeEnabled')
+
+	def set_BpeEnabled(self, BpeEnabled):  # String
+		self.add_query_param('BpeEnabled', BpeEnabled)
