@@ -23,7 +23,7 @@ from aliyunsdkrds.endpoint import endpoint_data
 class CreateGadInstanceMemberRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'CreateGadInstanceMember','rds')
+		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'CreateGadInstanceMember')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -92,5 +92,7 @@ class CreateGadInstanceMemberRequest(RpcRequest):
 				self.add_query_param('UnitNode.' + str(depth1 + 1) + '.ZoneID', UnitNode[depth1].get('ZoneID'))
 			if UnitNode[depth1].get('DBInstanceDescription') is not None:
 				self.add_query_param('UnitNode.' + str(depth1 + 1) + '.DBInstanceDescription', UnitNode[depth1].get('DBInstanceDescription'))
+			if UnitNode[depth1].get('DBInstanceStorageType') is not None:
+				self.add_query_param('UnitNode.' + str(depth1 + 1) + '.DBInstanceStorageType', UnitNode[depth1].get('DBInstanceStorageType'))
 			if UnitNode[depth1].get('DtsConflict') is not None:
 				self.add_query_param('UnitNode.' + str(depth1 + 1) + '.DtsConflict', UnitNode[depth1].get('DtsConflict'))
