@@ -23,76 +23,66 @@ from aliyunsdkrds.endpoint import endpoint_data
 class CreateMigrateTaskRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'CreateMigrateTask','rds')
+		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'CreateMigrateTask')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_IsOnlineDB(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_IsOnlineDB(self): # String
 		return self.get_query_params().get('IsOnlineDB')
 
-	def set_IsOnlineDB(self,IsOnlineDB):
-		self.add_query_param('IsOnlineDB',IsOnlineDB)
-
-	def get_DBInstanceId(self):
+	def set_IsOnlineDB(self, IsOnlineDB):  # String
+		self.add_query_param('IsOnlineDB', IsOnlineDB)
+	def get_DBInstanceId(self): # String
 		return self.get_query_params().get('DBInstanceId')
 
-	def set_DBInstanceId(self,DBInstanceId):
-		self.add_query_param('DBInstanceId',DBInstanceId)
-
-	def get_MigrateTaskId(self):
+	def set_DBInstanceId(self, DBInstanceId):  # String
+		self.add_query_param('DBInstanceId', DBInstanceId)
+	def get_MigrateTaskId(self): # String
 		return self.get_query_params().get('MigrateTaskId')
 
-	def set_MigrateTaskId(self,MigrateTaskId):
-		self.add_query_param('MigrateTaskId',MigrateTaskId)
-
-	def get_ResourceOwnerAccount(self):
+	def set_MigrateTaskId(self, MigrateTaskId):  # String
+		self.add_query_param('MigrateTaskId', MigrateTaskId)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_OwnerId(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_OssObjectPositions(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_OssObjectPositions(self): # String
 		return self.get_query_params().get('OssObjectPositions')
 
-	def set_OssObjectPositions(self,OssObjectPositions):
-		self.add_query_param('OssObjectPositions',OssObjectPositions)
-
-	def get_OSSUrls(self):
+	def set_OssObjectPositions(self, OssObjectPositions):  # String
+		self.add_query_param('OssObjectPositions', OssObjectPositions)
+	def get_OSSUrls(self): # String
 		return self.get_query_params().get('OSSUrls')
 
-	def set_OSSUrls(self,OSSUrls):
-		self.add_query_param('OSSUrls',OSSUrls)
-
-	def get_DBName(self):
+	def set_OSSUrls(self, OSSUrls):  # String
+		self.add_query_param('OSSUrls', OSSUrls)
+	def get_DBName(self): # String
 		return self.get_query_params().get('DBName')
 
-	def set_DBName(self,DBName):
-		self.add_query_param('DBName',DBName)
-
-	def get_BackupMode(self):
+	def set_DBName(self, DBName):  # String
+		self.add_query_param('DBName', DBName)
+	def get_BackupMode(self): # String
 		return self.get_query_params().get('BackupMode')
 
-	def set_BackupMode(self,BackupMode):
-		self.add_query_param('BackupMode',BackupMode)
-
-	def get_CheckDBMode(self):
+	def set_BackupMode(self, BackupMode):  # String
+		self.add_query_param('BackupMode', BackupMode)
+	def get_CheckDBMode(self): # String
 		return self.get_query_params().get('CheckDBMode')
 
-	def set_CheckDBMode(self,CheckDBMode):
-		self.add_query_param('CheckDBMode',CheckDBMode)
\ No newline at end of file
+	def set_CheckDBMode(self, CheckDBMode):  # String
+		self.add_query_param('CheckDBMode', CheckDBMode)
