@@ -23,7 +23,7 @@ from aliyunsdkrds.endpoint import endpoint_data
 class DescibeImportsFromDatabaseRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'DescibeImportsFromDatabase','rds')
+		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'DescibeImportsFromDatabase')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -51,6 +51,11 @@ class DescibeImportsFromDatabaseRequest(RpcRequest):
 
 	def set_PageNumber(self, PageNumber):  # Integer
 		self.add_query_param('PageNumber', PageNumber)
+	def get_ResourceGroupId(self): # String
+		return self.get_query_params().get('ResourceGroupId')
+
+	def set_ResourceGroupId(self, ResourceGroupId):  # String
+		self.add_query_param('ResourceGroupId', ResourceGroupId)
 	def get_ImportId(self): # Integer
 		return self.get_query_params().get('ImportId')
 
