@@ -23,58 +23,51 @@ from aliyunsdkrds.endpoint import endpoint_data
 class DescribeBackupPolicyRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'DescribeBackupPolicy','rds')
+		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'DescribeBackupPolicy')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_DBInstanceId(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_DBInstanceId(self): # String
 		return self.get_query_params().get('DBInstanceId')
 
-	def set_DBInstanceId(self,DBInstanceId):
-		self.add_query_param('DBInstanceId',DBInstanceId)
-
-	def get_BackupPolicyMode(self):
+	def set_DBInstanceId(self, DBInstanceId):  # String
+		self.add_query_param('DBInstanceId', DBInstanceId)
+	def get_BackupPolicyMode(self): # String
 		return self.get_query_params().get('BackupPolicyMode')
 
-	def set_BackupPolicyMode(self,BackupPolicyMode):
-		self.add_query_param('BackupPolicyMode',BackupPolicyMode)
-
-	def get_ReleasedKeepPolicy(self):
+	def set_BackupPolicyMode(self, BackupPolicyMode):  # String
+		self.add_query_param('BackupPolicyMode', BackupPolicyMode)
+	def get_ReleasedKeepPolicy(self): # String
 		return self.get_query_params().get('ReleasedKeepPolicy')
 
-	def set_ReleasedKeepPolicy(self,ReleasedKeepPolicy):
-		self.add_query_param('ReleasedKeepPolicy',ReleasedKeepPolicy)
-
-	def get_ResourceOwnerAccount(self):
+	def set_ReleasedKeepPolicy(self, ReleasedKeepPolicy):  # String
+		self.add_query_param('ReleasedKeepPolicy', ReleasedKeepPolicy)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_OwnerAccount(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_OwnerAccount(self): # String
 		return self.get_query_params().get('OwnerAccount')
 
-	def set_OwnerAccount(self,OwnerAccount):
-		self.add_query_param('OwnerAccount',OwnerAccount)
-
-	def get_CompressType(self):
+	def set_OwnerAccount(self, OwnerAccount):  # String
+		self.add_query_param('OwnerAccount', OwnerAccount)
+	def get_CompressType(self): # String
 		return self.get_query_params().get('CompressType')
 
-	def set_CompressType(self,CompressType):
-		self.add_query_param('CompressType',CompressType)
-
-	def get_OwnerId(self):
+	def set_CompressType(self, CompressType):  # String
+		self.add_query_param('CompressType', CompressType)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
\ No newline at end of file
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
