@@ -23,7 +23,7 @@ from aliyunsdkrds.endpoint import endpoint_data
 class DetachGadInstanceMemberRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'DetachGadInstanceMember','rds')
+		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'DetachGadInstanceMember')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -31,6 +31,11 @@ class DetachGadInstanceMemberRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_ResourceGroupId(self): # String
+		return self.get_query_params().get('ResourceGroupId')
+
+	def set_ResourceGroupId(self, ResourceGroupId):  # String
+		self.add_query_param('ResourceGroupId', ResourceGroupId)
 	def get_MemberInstanceName(self): # String
 		return self.get_query_params().get('MemberInstanceName')
 
