@@ -23,7 +23,7 @@ from aliyunsdkrds.endpoint import endpoint_data
 class ImportUserBackupFileRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'ImportUserBackupFile','rds')
+		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'ImportUserBackupFile')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -41,6 +41,11 @@ class ImportUserBackupFileRequest(RpcRequest):
 
 	def set_EngineVersion(self, EngineVersion):  # String
 		self.add_query_param('EngineVersion', EngineVersion)
+	def get_ResourceGroupId(self): # String
+		return self.get_query_params().get('ResourceGroupId')
+
+	def set_ResourceGroupId(self, ResourceGroupId):  # String
+		self.add_query_param('ResourceGroupId', ResourceGroupId)
 	def get_Retention(self): # Integer
 		return self.get_query_params().get('Retention')
 
