@@ -23,7 +23,7 @@ from aliyunsdkrds.endpoint import endpoint_data
 class RemoveTagsFromResourceRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'RemoveTagsFromResource','rds')
+		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'RemoveTagsFromResource')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -61,6 +61,11 @@ class RemoveTagsFromResourceRequest(RpcRequest):
 
 	def set_Tag1value(self, Tag1value):  # String
 		self.add_query_param('Tag.1.value', Tag1value)
+	def get_ResourceGroupId(self): # String
+		return self.get_query_params().get('ResourceGroupId')
+
+	def set_ResourceGroupId(self, ResourceGroupId):  # String
+		self.add_query_param('ResourceGroupId', ResourceGroupId)
 	def get_DBInstanceId(self): # String
 		return self.get_query_params().get('DBInstanceId')
 
