@@ -23,7 +23,7 @@ from aliyunsdkrds.endpoint import endpoint_data
 class UpdateUserBackupFileRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'UpdateUserBackupFile','rds')
+		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'UpdateUserBackupFile')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -36,6 +36,11 @@ class UpdateUserBackupFileRequest(RpcRequest):
 
 	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
 		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_ResourceGroupId(self): # String
+		return self.get_query_params().get('ResourceGroupId')
+
+	def set_ResourceGroupId(self, ResourceGroupId):  # String
+		self.add_query_param('ResourceGroupId', ResourceGroupId)
 	def get_Retention(self): # Integer
 		return self.get_query_params().get('Retention')
 
